import axios from "axios";

// --- Initialzustand ---
const initialState = {
  size: 16,
  text: "!",
  wikiText: ""
};

// --- Reducer ---
export default function reducer(state = initialState, action) {
  switch (action.type) {
    case "font/increase":
      return { ...state, size: state.size + 1 };
    case "font/decrease":
      return { ...state, size: state.size - 1 };
    case "font/reset":
      return { ...state, wikiText: "" }; // Nur Wiki-Text leeren
    case "text/update":
      return { ...state, text: action.payload };
    case "wiki/set":
      return { ...state, wikiText: action.payload };
    default:
      return state;
  }
}

// --- Hilfsfunktion zur Extraktion aus Wikipedia-Antwort ---
function getTextFromAxios(responseObj) {
  let str = "---";

  // Wenn kein "query"-Objekt vorhanden ist, abbrechen
  if (!responseObj.query) return "---";

  const keyVal = Object.keys(responseObj.query.pages)[0];
  const page = responseObj.query.pages[keyVal];

  // Wenn die Seite kein extract hat oder sie fehlt
  if (!page.extract || page.missing === "") return "---";

  str = page.extract;
  return str;
}

// --- Thunk-Funktion zum Laden von Wikipedia ---
export function fetchWiki() {
  return async (dispatch, getState) => {
    const searchTerm = getState().text;

    const url = `https://de.wikipedia.org/w/api.php?action=query&origin=*&prop=extracts&format=json&titles=${searchTerm}`;

    try {
      const response = await axios.get(url);
      const resText = getTextFromAxios(response.data);
      dispatch({ type: "wiki/set", payload: resText });
    } catch (error) {
      dispatch({ type: "wiki/set", payload: "Fehler beim Laden von Wikipedia." });
    }
  };
}
